=begin
Copyright 2013, Chris Fullmer
All Rights Reserved

Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

License
This software is distributed under the Smustard End User License Agreement
http://www.smustard.com/eula

Information
Author - Chris Fullmer with Stepped colorization by ICEPAM.
Organization - www.ChrisFullmer.com and distributed on the SketchUp Extension Warehouse and smustard.com
Name - Label Open Faces
SU Version - 2013, 8, 7

Description
This script adds a text label to every edge that borders only one face.  For example, every edge 
in a cube will be bounded by 2 faces, therefore no edges will be labeled.  A single flat face's 
edges will only bound 1 face, therefore all its edges will be labeled.  This is hopefully useful 
for making solid models, or "watertight" models.

Usage
Activate the plugin at Plugins>Chris Fullmer Tools>Label Open Faces.  If you have items selected, 
the script will only examine those items.  If nothing is selected, it will search the entire model.  
Note that this script does not dig down into groups and components at this point.

History
1.0:: 2009-03-26
   * First release
1.1.0 - 2013-05-20
  * EW Compatibility
=end

module CLF_Extensions_NS

  module CLF_Label_Open_Faces

    require 'sketchup.rb'
    require 'extensions.rb'
    
    NAME = "clf_label_open_faces"
    UNAME = "CLF Label Open Faces"
    MENU_NAME = "Label Open Faces"
    version = "1.1.0"
    desc = "This plugin helps find holes in components by adding a text label to each face that is not closed."
    copy_year = "2013"
    author = "Chris Fullmer"
    
#------edit above--------------------------------------------------------------- 

    
    extension = SketchupExtension.new UNAME, NAME+"/"+NAME+"_menus.rb"

    #The name= method sets the name which appears for an extension inside the Extensions Manager dialog.
    extension.name = UNAME

    # The description= method sets the long description which appears beneath an extension inside the Extensions Manager dialog.
    extension.description = desc + "  Access it via Plugins > Chris Fullmer Tools > "+MENU_NAME

    # The version method sets the version which appears beneath an extension inside the Extensions Manager dialog.
    extension.version = version

    # Create an entry in the Extension list that loads a script called
    # stairTools.rb.
    extension.copyright = copy_year
     
    # The creator= method sets the creator string which appears beneath an extension inside the Extensions Manager dialog.
    extension.creator = author

    # The register_extension method is used to register an extension with SketchUp's extension manager (in SketchUp preferences).
    Sketchup.register_extension( extension, true )
    
  end
  
end 